@@ -1,5 +1,5 @@
 package Array::FIFO;
-$Array::FIFO::VERSION = '0.07';
+$Array::FIFO::VERSION = '0.08';
 use Moose;
 use List::Util qw(sum0);
 
@@ -8,11 +8,11 @@ use namespace::autoclean;
 
 =head1 NAME
 
-Array::FIFO - A Simple limitable FIFO array, with some convenience methods to crunch the data
+Array::FIFO - A Simple limitable FIFO array, with sum and average methods
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -30,7 +30,7 @@ manner, with an optional limit to how large the array can get.  When the limit i
 reached, the oldest value is discarded when new values are added.
 
 It's intent is for numeric values (i.e. current load of a system), but it should work 
-for other data types.
+for other data types if you're not in need of the calculation methods.
 
 The C<sum> and C<average> methods keep the current sum and average of the numbers
 as you would expect.  It does this on demand.
